@@ -43,30 +43,6 @@ pub struct RunResult {
 #[derive(Debug)]
 pub struct Error(Box<dyn std::error::Error + Send + Sync>);
 
-impl From<&'_ str> for Error {
-	fn from(err: &'_ str) -> Self {
-		Error(err.into())
-	}
-}
-
-impl From<String> for Error {
-	fn from(err: String) -> Self {
-		Error(err.into())
-	}
-}
-
-impl From<std::fmt::Error> for Error {
-	fn from(err: std::fmt::Error) -> Self {
-		Error(err.into())
-	}
-}
-
-impl From<std::io::Error> for Error {
-	fn from(err: std::io::Error) -> Self {
-		Error(err.into())
-	}
-}
-
 impl std::fmt::Display for Error {
 	fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
 		self.0.fmt(f)
@@ -74,6 +50,28 @@ impl std::fmt::Display for Error {
 }
 
 impl std::error::Error for Error {
+	fn source(&self) -> Option<&(dyn std::error::Error + 'static)> {
+		self.0.source()
+	}
+}
+
+macro_rules! impl_from_for_error {
+	($($ty:ty ,)*) => {
+		$(
+			impl From<$ty> for Error {
+				fn from(err: $ty) -> Self {
+					Error(err.into())
+				}
+			}
+		)*
+	};
+}
+
+impl_from_for_error! {
+	&'_ str,
+	String,
+	std::fmt::Error,
+	std::io::Error,
 }
 
 /// A mechanism for converting (the components of) an openapi path to (the components of) a Rust namespace.
@@ -149,11 +147,11 @@ impl<T> RunState for &'_ mut T where T: RunState {
 	}
 }
 
-/// Whether [`run`] should generate an impl of [`schemars::JsonSchema`] for the type or not.
+/// Whether [`run`] should generate an impl of `schemars::JsonSchema` for the type or not.
 #[derive(Clone, Copy, Debug)]
 pub enum GenerateSchema<'a> {
 	Yes {
-		/// An optional feature that the impl of [`schemars::JsonSchema`] will be `cfg`-gated by.
+		/// An optional feature that the impl of `schemars::JsonSchema` will be `cfg`-gated by.
 		feature: Option<&'a str>,
 	},
 
@@ -276,7 +274,9 @@ pub fn run(
 					let mut field_type_name = String::new();
 
 					let required = match required {
-						true => templates::PropertyRequired::Required,
+						true => templates::PropertyRequired::Required {
+							is_default: is_default(&schema.kind, definitions, map_namespace)?,
+						},
 						false => templates::PropertyRequired::Optional,
 					};
 
@@ -470,7 +470,7 @@ pub fn run(
 			let template_resource_metadata = match (&resource_metadata, &metadata_ty) {
 				(
 					Some((api_version, group, kind, version, list_kind)),
-					Some((metadata_ty, templates::PropertyRequired::Required)),
+					Some((metadata_ty, templates::PropertyRequired::Required { is_default: _ })),
 				) => Some(templates::ResourceMetadata {
 					api_version,
 					group,
@@ -627,20 +627,6 @@ pub fn run(
 		},
 
 		swagger20::SchemaKind::Ty(swagger20::Type::WatchEvent(raw_extension_ref_path)) => {
-			let has_bookmark_event_type = {
-				let watch_optional_schema =
-					definitions.get(&swagger20::DefinitionPath("io.k8s.WatchOptional".to_owned()))
-					.ok_or("could not find io.k8s.WatchOptional")?;
-				let watch_optional_properties =
-					if let swagger20::SchemaKind::Ty(swagger20::Type::WatchOptional(properties)) = &watch_optional_schema.kind {
-						properties
-					}
-					else {
-						return Err("io.k8s.WatchOptional has unexpected schema kind".into());
-					};
-				watch_optional_properties.contains_key(&swagger20::PropertyName("allowWatchBookmarks".to_owned()))
-			};
-
 			let error_status_rust_type = get_rust_type(
 				&swagger20::SchemaKind::Ref(swagger20::RefPath {
 					path: "io.k8s.apimachinery.pkg.apis.meta.v1.Status".to_owned(),
@@ -657,7 +643,6 @@ pub fn run(
 			templates::watch_event::generate(
 				&mut out,
 				type_name,
-				has_bookmark_event_type,
 				&error_status_rust_type,
 				&error_other_rust_type,
 				map_namespace,
@@ -681,7 +666,7 @@ pub fn run(
 					comment: Some("List of objects."),
 					field_name: "items".into(),
 					field_type_name: "Vec<T>".to_owned(),
-					required: templates::PropertyRequired::Required,
+					required: templates::PropertyRequired::Required { is_default: true },
 					is_flattened: false,
 				},
 
@@ -690,7 +675,7 @@ pub fn run(
 					comment: Some("Standard list metadata. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds"),
 					field_name: "metadata".into(),
 					field_type_name: (&*metadata_rust_type).to_owned(),
-					required: templates::PropertyRequired::Required,
+					required: templates::PropertyRequired::Required { is_default: true },
 					is_flattened: false,
 				},
 			];
@@ -1194,6 +1179,49 @@ fn get_derives(
 	}))
 }
 
+fn is_default(
+	kind: &swagger20::SchemaKind,
+	definitions: &std::collections::BTreeMap<swagger20::DefinitionPath, swagger20::Schema>,
+	map_namespace: &impl MapNamespace,
+) -> Result<bool, Error> {
+	#[allow(clippy::match_same_arms)]
+	evaluate_trait_bound(kind, false, definitions, map_namespace, |kind, required| match kind {
+		// Option<T>::default is None regardless of T
+		_ if !required => Ok(true),
+
+		swagger20::SchemaKind::Ref(swagger20::RefPath { can_be_default: Some(can_be_default), .. }) => Ok(*can_be_default),
+
+		swagger20::SchemaKind::Ref(ref_path @ swagger20::RefPath { .. }) if ref_path.references_scope(map_namespace) => Ok(false),
+
+		// metadata field in resource type created by #[derive(CustomResourceDefinition)]
+		swagger20::SchemaKind::Ref(ref_path @ swagger20::RefPath { .. })
+			if !ref_path.references_scope(map_namespace) && ref_path.path == "io.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta" => Ok(true),
+
+		// Handled by evaluate_trait_bound
+		swagger20::SchemaKind::Ref(ref_path @ swagger20::RefPath { .. }) if !ref_path.references_scope(map_namespace) => unreachable!(),
+
+		// chrono::DateTime<chrono::Utc> is not Default
+		swagger20::SchemaKind::Ty(swagger20::Type::String { format: Some(swagger20::StringFormat::DateTime) }) => Ok(false),
+
+		// Enums without a default value
+		swagger20::SchemaKind::Ty(
+			swagger20::Type::JsonSchemaPropsOrArray(_) |
+			swagger20::Type::JsonSchemaPropsOrBool(_) |
+			swagger20::Type::JsonSchemaPropsOrStringArray(_) |
+			swagger20::Type::Patch |
+			swagger20::Type::WatchEvent(_) |
+			swagger20::Type::CreateResponse |
+			swagger20::Type::DeleteResponse |
+			swagger20::Type::ListResponse |
+			swagger20::Type::PatchResponse |
+			swagger20::Type::ReplaceResponse |
+			swagger20::Type::WatchResponse
+		) => Ok(false),
+
+		_ => Ok(true),
+	})
+}
+
 fn evaluate_trait_bound(
 	kind: &swagger20::SchemaKind,
 	array_follows_elements: bool,
@@ -1330,19 +1358,33 @@ fn evaluate_trait_bound(
 }
 
 fn get_comment_text<'a>(s: &'a str, indent: &'a str) -> impl Iterator<Item = std::borrow::Cow<'static, str>> + 'a {
-	s.lines().map(move |line|
+	s.lines().scan(true, move |previous_line_was_empty, line|
 		if line.is_empty() {
-			"".into()
+			*previous_line_was_empty = true;
+			Some("".into())
 		}
 		else {
 			let line =
 				line
-				.replace(r"\", r"\\")
-				.replace("[", r"\[")
-				.replace("]", r"\]")
-				.replace("<", r"\<")
-				.replace(">", r"\>");
-			format!("{} {}", indent, line).into()
+				.replace('\\', r"\\")
+				.replace('[', r"\[")
+				.replace(']', r"\]")
+				.replace('<', r"\<")
+				.replace('>', r"\>")
+				.replace('\t', "    ");
+
+			let line =
+				if *previous_line_was_empty && line.starts_with("    ") {
+					// Collapse this line's spaces into two. Otherwise rustdoc will think this is the start of a code block containing a Rust test.
+					format!("  {}", line.trim_start())
+				}
+				else {
+					line
+				};
+
+			*previous_line_was_empty = false;
+
+			Some(format!("{} {}", indent, line).into())
 		})
 }
 
@@ -1802,7 +1844,7 @@ pub fn write_operation(
 	}
 
 	if let Some(operation_feature) = operation_feature {
-		writeln!(out, r#"{}#[cfg(feature = "{}")]"#, indent, operation_feature)?;
+		writeln!(out, r#"{}#[cfg(feature = {:?})]"#, indent, operation_feature)?;
 	}
 
 	writeln!(out, "{}{}fn {}(", indent, vis, operation_fn_name)?;
@@ -2076,7 +2118,7 @@ pub fn write_operation(
 		}
 
 		if let Some(operation_feature) = operation_feature {
-			writeln!(out, r#"#[cfg(feature = "{}")]"#, operation_feature)?;
+			writeln!(out, r#"#[cfg(feature = {:?})]"#, operation_feature)?;
 		}
 		writeln!(out, "#[derive(Clone, Copy, Debug, Default)]")?;
 		write!(out, "{}struct {}", vis, operation_optional_parameters_name)?;
@@ -2118,7 +2160,7 @@ pub fn write_operation(
 			}
 
 			if let Some(operation_feature) = operation_feature {
-				writeln!(out, r#"#[cfg(feature = "{}")]"#, operation_feature)?;
+				writeln!(out, r#"#[cfg(feature = {:?})]"#, operation_feature)?;
 			}
 			writeln!(out, "#[derive(Debug)]")?;
 			writeln!(out, "{}enum {} {{", vis, operation_result_name)?;
@@ -2158,7 +2200,7 @@ pub fn write_operation(
 			writeln!(out)?;
 
 			if let Some(operation_feature) = operation_feature {
-				writeln!(out, r#"#[cfg(feature = "{}")]"#, operation_feature)?;
+				writeln!(out, r#"#[cfg(feature = {:?})]"#, operation_feature)?;
 			}
 			writeln!(out, "impl {}Response for {} {{", local, operation_result_name)?;
 			writeln!(out, "    fn try_from_parts(status_code: {local}http::StatusCode, buf: &[u8]) -> Result<(Self, usize), {local}ResponseError> {{", local = local)?;
@@ -2190,7 +2232,7 @@ pub fn write_operation(
 					swagger20::SchemaKind::Ref(_) => {
 						writeln!(out, "                let result = match {}serde_json::from_slice(buf) {{", local)?;
 						writeln!(out, "                    Ok(value) => value,")?;
-						writeln!(out, "                    Err(ref err) if err.is_eof() => return Err({}ResponseError::NeedMoreData),", local)?;
+						writeln!(out, "                    Err(err) if err.is_eof() => return Err({}ResponseError::NeedMoreData),", local)?;
 						writeln!(out, "                    Err(err) => return Err({}ResponseError::Json(err)),", local)?;
 						writeln!(out, "                }};")?;
 						writeln!(out, "                Ok(({}::{}(result), buf.len()))", operation_result_name, variant_name)?;
@@ -2209,7 +2251,7 @@ pub fn write_operation(
 			writeln!(out, "                    else {{")?;
 			writeln!(out, "                        match {}serde_json::from_slice(buf) {{", local)?;
 			writeln!(out, "                            Ok(value) => (Ok(Some(value)), buf.len()),")?;
-			writeln!(out, "                            Err(ref err) if err.is_eof() => return Err({}ResponseError::NeedMoreData),", local)?;
+			writeln!(out, "                            Err(err) if err.is_eof() => return Err({}ResponseError::NeedMoreData),", local)?;
 			writeln!(out, "                            Err(err) => (Err(err), 0),")?;
 			writeln!(out, "                        }}")?;
 			writeln!(out, "                    }};")?;
