@@ -30,37 +30,6 @@ pub(crate) mod type_header;
 
 pub(crate) mod watch_event;
 
-fn get_comment_text<'a>(s: &'a str, indent: &'a str) -> impl Iterator<Item = std::borrow::Cow<'static, str>> + 'a {
-	s.lines().scan(true, move |previous_line_was_empty, line|
-		if line.is_empty() {
-			*previous_line_was_empty = true;
-			Some("".into())
-		}
-		else {
-			let line =
-				line
-				.replace(r"\", r"\\")
-				.replace("[", r"\[")
-				.replace("]", r"\]")
-				.replace("<", r"\<")
-				.replace(">", r"\>")
-				.replace("\t", "    ");
-
-			let line =
-				if *previous_line_was_empty && line.starts_with("    ") {
-					// Collapse this line's spaces into two. Otherwise rustdoc will think this is the start of a code block containing a Rust test.
-					format!("  {}", line.trim_start())
-				}
-				else {
-					line
-				};
-
-			*previous_line_was_empty = false;
-
-			Some(format!("{} {}", indent, line).into())
-		})
-}
-
 #[derive(Clone, Copy, Default)]
 pub(crate) struct Generics<'a> {
 	pub(crate) type_part: Option<&'a str>,
@@ -78,7 +47,7 @@ pub(crate) struct Property<'a> {
 
 #[derive(Clone, Copy)]
 pub(crate) enum PropertyRequired {
-	Required,
+	Required { is_default: bool },
 	Optional,
 
 	// TODO:
